# TSCCM

**TSCCM** *(Tenable.SC CLI Manager)* by LimberDuck is a CLI tool which enables you to perform certain actions on Tenable.SC by (C) Tenable, Inc. via [Tenable.SC API](https://docs.tenable.com/tenablesc/api).

[![License](https://img.shields.io/github/license/LimberDuck/tsccm.svg)](https://github.com/LimberDuck/tsccm/blob/master/LICENSE) [![Repo size](https://img.shields.io/github/repo-size/LimberDuck/tsccm.svg)](https://github.com/LimberDuck/tsccm) [![Code size](https://img.shields.io/github/languages/code-size/LimberDuck/tsccm.svg)](https://github.com/LimberDuck/tsccm) [![Supported platform](https://img.shields.io/badge/platform-windows%20%7C%20macos%20%7C%20linux-lightgrey.svg)](https://github.com/LimberDuck/tsccm)


Main features
=============

Initial version of **TSCCM** lets you get Tenable.SC's:
* active scans list
* scan results list
* policies list
* credentials list  
* users list
* groups list
* status of available IPs


How to
======

1. Install
    
    `pip install tsccm`

2. Run

    `tsccm`

Meta
====

Change log
----------

See [CHANGELOG].


Licence
-------

MIT: [LICENSE].


Authors
-------

[Damian Krawczyk] created **TSCCM** *(Tenable.SC CLI Manager)* by LimberDuck.

[Damian Krawczyk]: https://damiankrawczyk.com

[CHANGELOG]: https://github.com/LimberDuck/tsccm/blob/master/CHANGELOG.md
[LICENSE]: https://github.com/LimberDuck/tsccm/blob/master/LICENSE


